    echo off

REM Produces full sky-hemisphere plot of antenna performance from a NEC output file.
REM Annotates plot with comments from the NEC input card deck.
REM Annotates plot with key statistics, including antenna performance within 3 zones defined by the target.xy file.
REM
REM Call:
REM   nouplot <NEC output filename> <target filename>
REM The target zones used to calculate statistics are defined by the file target.xy
REM This file has two lines each containing 4 integers and a word:
REM    Target 1: az-left to az-right, el-lo to el-hi, name (one word)
REM    Target 2: az-left to az-right, el-lo to el-hi, name (one word)
REM If a target zone is not needed, set the azimuths or elevations equal to each other.
REM Both lines are REQUIRED, even if target zone(s) are not needed.
REM
REM NOTE: Points in Target zone 1 are EXCLUDED from the statistics for Target zone 2.
REM
REM 01 May 14: Added target area outlines.
REM 01 May 14: Added axis labels.
REM 01 May 14: Corrected mu in legend to long dash.
REM 01 May 14: Make color scale same height as chart.
REM 01 May 14: Changing grdview to -Qi from -Q2 shrinks postcript file from 8MB to 1MB.
REM 02 Aug 08: Change .gmtdefaults to use landscape page format.
REM 02 Aug 09: Corrected use of -K (omit trailer) and -O (omit header) for the Postscript overlay system.
REM 02 Aug 09: Changed from -JKf180 (Eckert IV project with south centered) to -JKf0 (with north centered).
REM            Requires -R0/360/0/90 to change to -R-180/180/0/90
REM            Requires grdview not to use -E viewing point definition as -E0/0 doesn't work.
REM 02 Aug 09: Draw target areas with white pen 255/255/255 for better contrast to presumably colored data.
REM 02 Aug 09: Expanded width of plot to 10.5 inches.  Moved scale legend to top-right corner.
REM 02 Aug 10: Fixed plotting of NEC comment cards in lower left column.
REM 02 Aug 13: Generated statistics for two target zones using GAWK.
REM 02 Aug 13: Generated statistics for non-targeted area using GAWK.
REM 02 Aug 13: target.xy is used to define target regions; borders generated by gawk for GMT plotting.
REM 02 Aug 14: Extract ground, freq, and impedances from NOU.
REM 03 Jan 27: Grdmath EXTREMA to extract local max/min.
REM 03 Jul  4: Right column of statistics made wider (see also NOUTrim.awk v2.4).

REM Remove old plot output file.
    del %1.ps

REM reformat the data
    gawk -f noutrim.awk target.xy %1.nou

REM convert to even grid
    gmtconvert %1.aeg -bo >%1.bin
    blockmean %1.bin -bid -I1 -L -R-180/180/0/90 -bod >%1.b
    surface %1.b -bd -G%1.grd -I1 -R-180/180/0/90 -C0.05

REM The data plot will be in the top half of the screen; therefore use -Xa0.25i -Ya4.50i.
    REM plot the data in top half of screen, using dBi.cpt to color.
	gmtset UNIX_TIME_POS 0i/3.375i
	gmtset BASEMAP_FRAME_RGB 160/160/160
	gmtset GRID_CROSS_SIZE 0.05i
	grdview %1.grd -JKf0/10.5i -Ba15g15/a10g10S -CdBi.cpt -K -Lg -Qi -R-180/180/0/90 -U"\216 Eric Scace K3NA - NEC-4 filename: %1" -Xa0.25i -Ya4.50i >>%1.ps

    REM Anotate axes on sides, top.  Note: GMT doesn't anotate these values, or incorrectly positions the labels, so we must add this manually.
    REM Use -X, -Y offsets to be 1/4 inch to the left, and 3/4 inch below of the map's plotted location.
    REM -R definition places 0,0 at lower left corner of the map itself.  Text plotting locations are therefore relative to the map's lower left corner.
	pstext AxisLabel.txt -JX11i/3.75i -R-0.25/10.75/-0.75/3 -G160 -K -O -Xa0i -Ya3.75i >>%1.ps

    REM Plot continental azimuth ranges, using a series of boxes and then adding the titles.
	psxy ContinentBoxesW3.xy -JX11i/3.75i -R-0.25/10.75/-0.75/3 -K -L -M -O -W0.25/160 -Xa0i -Ya3.75i >>%1.ps
	pstext ContinentsW3.txt -JX11i/3.75i -R-0.25/10.75/-0.75/3 -C0.02 -G160 -K -O -Xa0i -Ya3.75i >>%1.ps

    REM Plot the contours
	gmtset BASEMAP_FRAME_RGB 0/0/0
	grdcontour %1.grd -A3f6t -JKf0/10.5i -R-180/180/0/90 -G2i -K -L0 -O -W0.25p/0/0/0 -Xa0.25i -Ya4.50i >>%1.ps
	grdcontour %1.grd -A3f6t -JKf0/10.5i -R-180/180/0/90 -G2i -K -L-15/-3 -O -W0.25p/0/0/0/ta -Xa0.25i -Ya4.50i >>%1.ps

    REM Draw target areas with white pen
	psxy targetvertical.xy -JKf0/10.5i -R-180/180/0/90 -K -M -O -W0.25p/255/255/255 -Xa0.25i -Ya4.50i >>%1.ps
	psxy targethorizontal.xy -JKf0/10.5i -R-180/180/0/90 -A -K -M -O -W0.25p/255/255/255 -Xa0.25i -Ya4.50i >>%1.ps

    REM Find the local maxima and minima.
        grdmath %1.grd EXTREMA = maxmin.grd


    REM Plot the color scale. Note: dBi_scace.cpt file is used so that the scale ends at -21 dBi and markers appear at correct places.
	psscale -D8.00i/3.50i/5.0i/0.125ih -Bg1a3:"gain [dBi]": -CdBi_scale.cpt -K -O -Xa0.25i -Ya4.50i >>%1.ps

REM Note: each annotation area is controlled by the pstext boundaries AND by commands contained in the first line of the .COM, .CON and .DAT files.
REM To change column widths, one must change both the pstext and the first line of those files.
REM Annotate with NEC comment cards below figure in lower left column.
REM hint: Add -B to view border of print area.
    pstext %1.CM -JX4i/3.5i -R0/4/0/3.5 -K -M -O -Xa0.25i -Ya0.25i >>%1.ps

REM Annotate with frequency, ground, and drive impedance(s) in center column.
    pstext %1.CON -JX2i/3.5i -R0/2/0/3.5 -K -M -O -Xa4.50i -Ya0.25i >>%1.ps

REM Display statistics below figure in lower right column (use placeholder file).
REM hint: Add -B to view border of print area.
REM No -K: this is the last item plotted.
    pstext %1.dat -JX4i/3.5i -R0/4/0/3.5 -M -O -Xa6.75i -Ya0.25i >>%1.ps

REM Finished.
